package
module
Version:
v0.0.0-...-9645863
Opens a new window with list of versions in this module.
Published: May 28, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type ServerStatusJSON struct {
CPULoadAvg float64 `json:"cpu_load_avg"`
ActiveTasks int `json:"active_tasks"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.